debug

package
v5.8.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BlockHandler

func BlockHandler() gin.HandlerFunc

BlockHandler returns a handler for pprof block profile.

func CmdlineHandler

func CmdlineHandler() gin.HandlerFunc

CmdlineHandler returns a handler for the command line invocation.

func GoroutineHandler

func GoroutineHandler() gin.HandlerFunc

GoroutineHandler returns a handler for pprof goroutine stack traces.

func HeapHandler

func HeapHandler() gin.HandlerFunc

HeapHandler returns a handler for pprof heap dump.

func IndexHandler

func IndexHandler() gin.HandlerFunc

IndexHandler returns a handler that lists available pprof profiles.

func ProfileHandler

func ProfileHandler() gin.HandlerFunc

ProfileHandler returns a handler for pprof CPU profile.

func SymbolHandler

func SymbolHandler() gin.HandlerFunc

SymbolHandler returns a handler for pprof symbol lookup.

func ThreadCreateHandler

func ThreadCreateHandler() gin.HandlerFunc

ThreadCreateHandler returns a handler for pprof threadcreate profile.

func TraceHandler

func TraceHandler() gin.HandlerFunc

TraceHandler returns a handler for pprof execution trace.

Types

This section is empty.

Jump to