Documentation
¶
Index ¶
- Variables
- func AnnotateAutoscalerProvisioning(s store.Store, pipeline *model.Pipeline)
- func Approve(ctx context.Context, store store.Store, currentPipeline *model.Pipeline, ...) (*model.Pipeline, error)
- func Cancel(ctx context.Context, _forge forge.Forge, store store.Store, repo *model.Repo, ...) error
- func CancelWorkflow(ctx context.Context, _forge forge.Forge, store store.Store, repo *model.Repo, ...) error
- func Create(ctx context.Context, _store store.Store, repo *model.Repo, ...) (*model.Pipeline, error)
- func Decline(ctx context.Context, store store.Store, pipeline *model.Pipeline, ...) (*model.Pipeline, error)
- func RerunWorkflow(ctx context.Context, _forge forge.Forge, _store store.Store, ...) error
- func Restart(ctx context.Context, store store.Store, lastPipeline *model.Pipeline, ...) (*model.Pipeline, error)
- func UpdateStatusToDone(store store.Store, pipeline model.Pipeline, status model.StatusValue, ...) (*model.Pipeline, error)
- func UpdateStepStatus(store store.Store, step *model.Step, state rpc.StepState) error
- func UpdateStepStatusToDone(store store.Store, step model.Step, state rpc.StepState) (*model.Step, error)
- func UpdateStepToStatusKilled(store store.Store, step model.Step) (*model.Step, error)
- func UpdateStepToStatusSkipped(store store.Store, step model.Step, finished int64) (*model.Step, error)
- func UpdateStepToStatusStarted(store store.Store, step model.Step, state rpc.StepState) (*model.Step, error)
- func UpdateToStatusDeclined(store store.Store, pipeline model.Pipeline, reviewer string) (*model.Pipeline, error)
- func UpdateToStatusError(store store.Store, pipeline model.Pipeline, err error) (*model.Pipeline, error)
- func UpdateToStatusKilled(store store.Store, pipeline model.Pipeline) (*model.Pipeline, error)
- func UpdateToStatusPending(store store.Store, pipeline model.Pipeline, reviewer string) (*model.Pipeline, error)
- func UpdateToStatusRunning(store store.Store, pipeline model.Pipeline, started int64) (*model.Pipeline, error)
- func UpdateWorkflowStatusToDone(store store.Store, workflow model.Workflow, state rpc.WorkflowState) (*model.Workflow, error)
- func UpdateWorkflowStatusToRunning(store store.Store, workflow model.Workflow, state rpc.WorkflowState) (*model.Workflow, error)
- func UpdateWorkflowToStatusKilled(store store.Store, workflow model.Workflow) (*model.Workflow, error)
- func UpdateWorkflowToStatusSkipped(store store.Store, workflow model.Workflow) (*model.Workflow, error)
- type CreateOptions
- type ErrBadRequest
- type ErrNotFound
Constants ¶
This section is empty.
Variables ¶
var ErrFiltered = errors.New("ignoring hook: 'when' filters filtered out all steps")
Functions ¶
func AnnotateAutoscalerProvisioning ¶ added in v5.6.0
AnnotateAutoscalerProvisioning sets AutoscalerProvisioning on pending workflows when a healthy autoscaler with pending agents can match the workflow's task labels.
func Approve ¶
func Approve(ctx context.Context, store store.Store, currentPipeline *model.Pipeline, user *model.User, repo *model.Repo) (*model.Pipeline, error)
Approve update the status to pending for a blocked pipeline so it can be executed.
func Cancel ¶
func Cancel(ctx context.Context, _forge forge.Forge, store store.Store, repo *model.Repo, user *model.User, pipeline *model.Pipeline) error
Cancel the pipeline and returns the status.
func CancelWorkflow ¶
func CancelWorkflow(ctx context.Context, _forge forge.Forge, store store.Store, repo *model.Repo, user *model.User, pipeline *model.Pipeline, workflowID int64) error
CancelWorkflow cancels a specific workflow and returns the status.
func Create ¶
func Create(ctx context.Context, _store store.Store, repo *model.Repo, pipeline *model.Pipeline, opts ...CreateOptions) (*model.Pipeline, error)
Create a new pipeline and start it.
func Decline ¶
func Decline(ctx context.Context, store store.Store, pipeline *model.Pipeline, user *model.User, repo *model.Repo) (*model.Pipeline, error)
Decline updates the status to declined for blocked pipelines.
func RerunWorkflow ¶ added in v5.5.0
func RerunWorkflow(ctx context.Context, _forge forge.Forge, _store store.Store, currentPipeline *model.Pipeline, workflowID int64, user *model.User, repo *model.Repo) error
RerunWorkflow reruns a specific workflow within an existing pipeline. It creates new workflow+step records (preserving the original) and queues them for execution. If the rerun'd workflow has dependents that failed/were skipped, those are also rerun.
func Restart ¶
func Restart(ctx context.Context, store store.Store, lastPipeline *model.Pipeline, user *model.User, repo *model.Repo, envs map[string]string) (*model.Pipeline, error)
Restart a pipeline by creating a new one out of the old and start it.
func UpdateStatusToDone ¶
func UpdateStepStatus ¶
func UpdateStepStatusToDone ¶
func UpdateToStatusDeclined ¶
func UpdateToStatusError ¶
func UpdateToStatusKilled ¶
func UpdateToStatusPending ¶
func UpdateToStatusRunning ¶
Types ¶
type CreateOptions ¶
type CreateOptions struct {
WorkflowFilter []string // If set, only run workflows with these names
}
CreateOptions holds optional parameters for pipeline creation.
type ErrBadRequest ¶
type ErrBadRequest struct {
Msg string
}
func (ErrBadRequest) Error ¶
func (e ErrBadRequest) Error() string
func (ErrBadRequest) Is ¶
func (e ErrBadRequest) Is(target error) bool
type ErrNotFound ¶
type ErrNotFound struct {
Msg string
}
func (ErrNotFound) Error ¶
func (e ErrNotFound) Error() string
func (ErrNotFound) Is ¶
func (e ErrNotFound) Is(target error) bool