Documentation
¶
Index ¶
- type MockService
- func (_mock *MockService) CheckAccess(integration *model.Integration, userID int64, orgID int64, repoID int64) error
- func (_mock *MockService) Close()
- func (_m *MockService) EXPECT() *MockService_Expecter
- func (_mock *MockService) FetchSecret(ctx context.Context, ref *model.ExternalSecretRef, userID int64, orgID int64, ...) (string, error)
- func (_mock *MockService) FetchSecretsBatch(ctx context.Context, refs []*model.ExternalSecretRef, userID int64, ...) (map[string]string, error)
- func (_mock *MockService) GetProvider(ctx context.Context, integrationID int64, pipelineID int64) (integrations.Provider, error)
- func (_mock *MockService) IntegrationCreate(integration *model.Integration) error
- func (_mock *MockService) IntegrationDelete(userID int64, integrationID int64) error
- func (_mock *MockService) IntegrationFind(userID int64, integrationID int64) (*model.Integration, error)
- func (_mock *MockService) IntegrationFindByID(integrationID int64) (*model.Integration, error)
- func (_mock *MockService) IntegrationList(userID int64, opts *model.ListOptions) ([]*model.Integration, error)
- func (_mock *MockService) IntegrationListAccessible(userID int64, orgIDs []int64, repoIDs []int64, opts *model.ListOptions) ([]*model.Integration, error)
- func (_mock *MockService) IntegrationUpdate(integration *model.Integration) error
- func (_mock *MockService) ReleasePipeline(pipelineID int64)
- func (_mock *MockService) TestConnection(integration *model.Integration) error
- type MockService_CheckAccess_Call
- type MockService_Close_Call
- type MockService_Expecter
- func (_e *MockService_Expecter) CheckAccess(integration interface{}, userID interface{}, orgID interface{}, ...) *MockService_CheckAccess_Call
- func (_e *MockService_Expecter) Close() *MockService_Close_Call
- func (_e *MockService_Expecter) FetchSecret(ctx interface{}, ref interface{}, userID interface{}, orgID interface{}, ...) *MockService_FetchSecret_Call
- func (_e *MockService_Expecter) FetchSecretsBatch(ctx interface{}, refs interface{}, userID interface{}, orgID interface{}, ...) *MockService_FetchSecretsBatch_Call
- func (_e *MockService_Expecter) GetProvider(ctx interface{}, integrationID interface{}, pipelineID interface{}) *MockService_GetProvider_Call
- func (_e *MockService_Expecter) IntegrationCreate(integration interface{}) *MockService_IntegrationCreate_Call
- func (_e *MockService_Expecter) IntegrationDelete(userID interface{}, integrationID interface{}) *MockService_IntegrationDelete_Call
- func (_e *MockService_Expecter) IntegrationFind(userID interface{}, integrationID interface{}) *MockService_IntegrationFind_Call
- func (_e *MockService_Expecter) IntegrationFindByID(integrationID interface{}) *MockService_IntegrationFindByID_Call
- func (_e *MockService_Expecter) IntegrationList(userID interface{}, opts interface{}) *MockService_IntegrationList_Call
- func (_e *MockService_Expecter) IntegrationListAccessible(userID interface{}, orgIDs interface{}, repoIDs interface{}, opts interface{}) *MockService_IntegrationListAccessible_Call
- func (_e *MockService_Expecter) IntegrationUpdate(integration interface{}) *MockService_IntegrationUpdate_Call
- func (_e *MockService_Expecter) ReleasePipeline(pipelineID interface{}) *MockService_ReleasePipeline_Call
- func (_e *MockService_Expecter) TestConnection(integration interface{}) *MockService_TestConnection_Call
- type MockService_FetchSecret_Call
- type MockService_FetchSecretsBatch_Call
- func (_c *MockService_FetchSecretsBatch_Call) Return(stringToString map[string]string, err error) *MockService_FetchSecretsBatch_Call
- func (_c *MockService_FetchSecretsBatch_Call) Run(...) *MockService_FetchSecretsBatch_Call
- func (_c *MockService_FetchSecretsBatch_Call) RunAndReturn(...) *MockService_FetchSecretsBatch_Call
- type MockService_GetProvider_Call
- func (_c *MockService_GetProvider_Call) Return(provider integrations.Provider, err error) *MockService_GetProvider_Call
- func (_c *MockService_GetProvider_Call) Run(run func(ctx context.Context, integrationID int64, pipelineID int64)) *MockService_GetProvider_Call
- func (_c *MockService_GetProvider_Call) RunAndReturn(...) *MockService_GetProvider_Call
- type MockService_IntegrationCreate_Call
- func (_c *MockService_IntegrationCreate_Call) Return(err error) *MockService_IntegrationCreate_Call
- func (_c *MockService_IntegrationCreate_Call) Run(run func(integration *model.Integration)) *MockService_IntegrationCreate_Call
- func (_c *MockService_IntegrationCreate_Call) RunAndReturn(run func(integration *model.Integration) error) *MockService_IntegrationCreate_Call
- type MockService_IntegrationDelete_Call
- func (_c *MockService_IntegrationDelete_Call) Return(err error) *MockService_IntegrationDelete_Call
- func (_c *MockService_IntegrationDelete_Call) Run(run func(userID int64, integrationID int64)) *MockService_IntegrationDelete_Call
- func (_c *MockService_IntegrationDelete_Call) RunAndReturn(run func(userID int64, integrationID int64) error) *MockService_IntegrationDelete_Call
- type MockService_IntegrationFindByID_Call
- func (_c *MockService_IntegrationFindByID_Call) Return(integration *model.Integration, err error) *MockService_IntegrationFindByID_Call
- func (_c *MockService_IntegrationFindByID_Call) Run(run func(integrationID int64)) *MockService_IntegrationFindByID_Call
- func (_c *MockService_IntegrationFindByID_Call) RunAndReturn(run func(integrationID int64) (*model.Integration, error)) *MockService_IntegrationFindByID_Call
- type MockService_IntegrationFind_Call
- func (_c *MockService_IntegrationFind_Call) Return(integration *model.Integration, err error) *MockService_IntegrationFind_Call
- func (_c *MockService_IntegrationFind_Call) Run(run func(userID int64, integrationID int64)) *MockService_IntegrationFind_Call
- func (_c *MockService_IntegrationFind_Call) RunAndReturn(run func(userID int64, integrationID int64) (*model.Integration, error)) *MockService_IntegrationFind_Call
- type MockService_IntegrationListAccessible_Call
- func (_c *MockService_IntegrationListAccessible_Call) Return(integrations1 []*model.Integration, err error) *MockService_IntegrationListAccessible_Call
- func (_c *MockService_IntegrationListAccessible_Call) Run(...) *MockService_IntegrationListAccessible_Call
- func (_c *MockService_IntegrationListAccessible_Call) RunAndReturn(...) *MockService_IntegrationListAccessible_Call
- type MockService_IntegrationList_Call
- func (_c *MockService_IntegrationList_Call) Return(integrations1 []*model.Integration, err error) *MockService_IntegrationList_Call
- func (_c *MockService_IntegrationList_Call) Run(run func(userID int64, opts *model.ListOptions)) *MockService_IntegrationList_Call
- func (_c *MockService_IntegrationList_Call) RunAndReturn(run func(userID int64, opts *model.ListOptions) ([]*model.Integration, error)) *MockService_IntegrationList_Call
- type MockService_IntegrationUpdate_Call
- func (_c *MockService_IntegrationUpdate_Call) Return(err error) *MockService_IntegrationUpdate_Call
- func (_c *MockService_IntegrationUpdate_Call) Run(run func(integration *model.Integration)) *MockService_IntegrationUpdate_Call
- func (_c *MockService_IntegrationUpdate_Call) RunAndReturn(run func(integration *model.Integration) error) *MockService_IntegrationUpdate_Call
- type MockService_ReleasePipeline_Call
- func (_c *MockService_ReleasePipeline_Call) Return() *MockService_ReleasePipeline_Call
- func (_c *MockService_ReleasePipeline_Call) Run(run func(pipelineID int64)) *MockService_ReleasePipeline_Call
- func (_c *MockService_ReleasePipeline_Call) RunAndReturn(run func(pipelineID int64)) *MockService_ReleasePipeline_Call
- type MockService_TestConnection_Call
- func (_c *MockService_TestConnection_Call) Return(err error) *MockService_TestConnection_Call
- func (_c *MockService_TestConnection_Call) Run(run func(integration *model.Integration)) *MockService_TestConnection_Call
- func (_c *MockService_TestConnection_Call) RunAndReturn(run func(integration *model.Integration) error) *MockService_TestConnection_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockService ¶
MockService is an autogenerated mock type for the Service type
func NewMockService ¶
func NewMockService(t interface {
mock.TestingT
Cleanup(func())
}) *MockService
NewMockService creates a new instance of MockService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockService) CheckAccess ¶
func (_mock *MockService) CheckAccess(integration *model.Integration, userID int64, orgID int64, repoID int64) error
CheckAccess provides a mock function for the type MockService
func (*MockService) Close ¶
func (_mock *MockService) Close()
Close provides a mock function for the type MockService
func (*MockService) EXPECT ¶
func (_m *MockService) EXPECT() *MockService_Expecter
func (*MockService) FetchSecret ¶
func (_mock *MockService) FetchSecret(ctx context.Context, ref *model.ExternalSecretRef, userID int64, orgID int64, repoID int64, pipelineID int64) (string, error)
FetchSecret provides a mock function for the type MockService
func (*MockService) FetchSecretsBatch ¶
func (_mock *MockService) FetchSecretsBatch(ctx context.Context, refs []*model.ExternalSecretRef, userID int64, orgID int64, repoID int64, pipelineID int64) (map[string]string, error)
FetchSecretsBatch provides a mock function for the type MockService
func (*MockService) GetProvider ¶
func (_mock *MockService) GetProvider(ctx context.Context, integrationID int64, pipelineID int64) (integrations.Provider, error)
GetProvider provides a mock function for the type MockService
func (*MockService) IntegrationCreate ¶
func (_mock *MockService) IntegrationCreate(integration *model.Integration) error
IntegrationCreate provides a mock function for the type MockService
func (*MockService) IntegrationDelete ¶
func (_mock *MockService) IntegrationDelete(userID int64, integrationID int64) error
IntegrationDelete provides a mock function for the type MockService
func (*MockService) IntegrationFind ¶
func (_mock *MockService) IntegrationFind(userID int64, integrationID int64) (*model.Integration, error)
IntegrationFind provides a mock function for the type MockService
func (*MockService) IntegrationFindByID ¶
func (_mock *MockService) IntegrationFindByID(integrationID int64) (*model.Integration, error)
IntegrationFindByID provides a mock function for the type MockService
func (*MockService) IntegrationList ¶
func (_mock *MockService) IntegrationList(userID int64, opts *model.ListOptions) ([]*model.Integration, error)
IntegrationList provides a mock function for the type MockService
func (*MockService) IntegrationListAccessible ¶
func (_mock *MockService) IntegrationListAccessible(userID int64, orgIDs []int64, repoIDs []int64, opts *model.ListOptions) ([]*model.Integration, error)
IntegrationListAccessible provides a mock function for the type MockService
func (*MockService) IntegrationUpdate ¶
func (_mock *MockService) IntegrationUpdate(integration *model.Integration) error
IntegrationUpdate provides a mock function for the type MockService
func (*MockService) ReleasePipeline ¶
func (_mock *MockService) ReleasePipeline(pipelineID int64)
ReleasePipeline provides a mock function for the type MockService
func (*MockService) TestConnection ¶
func (_mock *MockService) TestConnection(integration *model.Integration) error
TestConnection provides a mock function for the type MockService
type MockService_CheckAccess_Call ¶
MockService_CheckAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CheckAccess'
func (*MockService_CheckAccess_Call) Return ¶
func (_c *MockService_CheckAccess_Call) Return(err error) *MockService_CheckAccess_Call
func (*MockService_CheckAccess_Call) Run ¶
func (_c *MockService_CheckAccess_Call) Run(run func(integration *model.Integration, userID int64, orgID int64, repoID int64)) *MockService_CheckAccess_Call
func (*MockService_CheckAccess_Call) RunAndReturn ¶
func (_c *MockService_CheckAccess_Call) RunAndReturn(run func(integration *model.Integration, userID int64, orgID int64, repoID int64) error) *MockService_CheckAccess_Call
type MockService_Close_Call ¶
MockService_Close_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Close'
func (*MockService_Close_Call) Return ¶
func (_c *MockService_Close_Call) Return() *MockService_Close_Call
func (*MockService_Close_Call) Run ¶
func (_c *MockService_Close_Call) Run(run func()) *MockService_Close_Call
func (*MockService_Close_Call) RunAndReturn ¶
func (_c *MockService_Close_Call) RunAndReturn(run func()) *MockService_Close_Call
type MockService_Expecter ¶
type MockService_Expecter struct {
// contains filtered or unexported fields
}
func (*MockService_Expecter) CheckAccess ¶
func (_e *MockService_Expecter) CheckAccess(integration interface{}, userID interface{}, orgID interface{}, repoID interface{}) *MockService_CheckAccess_Call
CheckAccess is a helper method to define mock.On call
- integration *model.Integration
- userID int64
- orgID int64
- repoID int64
func (*MockService_Expecter) Close ¶
func (_e *MockService_Expecter) Close() *MockService_Close_Call
Close is a helper method to define mock.On call
func (*MockService_Expecter) FetchSecret ¶
func (_e *MockService_Expecter) FetchSecret(ctx interface{}, ref interface{}, userID interface{}, orgID interface{}, repoID interface{}, pipelineID interface{}) *MockService_FetchSecret_Call
FetchSecret is a helper method to define mock.On call
- ctx context.Context
- ref *model.ExternalSecretRef
- userID int64
- orgID int64
- repoID int64
- pipelineID int64
func (*MockService_Expecter) FetchSecretsBatch ¶
func (_e *MockService_Expecter) FetchSecretsBatch(ctx interface{}, refs interface{}, userID interface{}, orgID interface{}, repoID interface{}, pipelineID interface{}) *MockService_FetchSecretsBatch_Call
FetchSecretsBatch is a helper method to define mock.On call
- ctx context.Context
- refs []*model.ExternalSecretRef
- userID int64
- orgID int64
- repoID int64
- pipelineID int64
func (*MockService_Expecter) GetProvider ¶
func (_e *MockService_Expecter) GetProvider(ctx interface{}, integrationID interface{}, pipelineID interface{}) *MockService_GetProvider_Call
GetProvider is a helper method to define mock.On call
- ctx context.Context
- integrationID int64
- pipelineID int64
func (*MockService_Expecter) IntegrationCreate ¶
func (_e *MockService_Expecter) IntegrationCreate(integration interface{}) *MockService_IntegrationCreate_Call
IntegrationCreate is a helper method to define mock.On call
- integration *model.Integration
func (*MockService_Expecter) IntegrationDelete ¶
func (_e *MockService_Expecter) IntegrationDelete(userID interface{}, integrationID interface{}) *MockService_IntegrationDelete_Call
IntegrationDelete is a helper method to define mock.On call
- userID int64
- integrationID int64
func (*MockService_Expecter) IntegrationFind ¶
func (_e *MockService_Expecter) IntegrationFind(userID interface{}, integrationID interface{}) *MockService_IntegrationFind_Call
IntegrationFind is a helper method to define mock.On call
- userID int64
- integrationID int64
func (*MockService_Expecter) IntegrationFindByID ¶
func (_e *MockService_Expecter) IntegrationFindByID(integrationID interface{}) *MockService_IntegrationFindByID_Call
IntegrationFindByID is a helper method to define mock.On call
- integrationID int64
func (*MockService_Expecter) IntegrationList ¶
func (_e *MockService_Expecter) IntegrationList(userID interface{}, opts interface{}) *MockService_IntegrationList_Call
IntegrationList is a helper method to define mock.On call
- userID int64
- opts *model.ListOptions
func (*MockService_Expecter) IntegrationListAccessible ¶
func (_e *MockService_Expecter) IntegrationListAccessible(userID interface{}, orgIDs interface{}, repoIDs interface{}, opts interface{}) *MockService_IntegrationListAccessible_Call
IntegrationListAccessible is a helper method to define mock.On call
- userID int64
- orgIDs []int64
- repoIDs []int64
- opts *model.ListOptions
func (*MockService_Expecter) IntegrationUpdate ¶
func (_e *MockService_Expecter) IntegrationUpdate(integration interface{}) *MockService_IntegrationUpdate_Call
IntegrationUpdate is a helper method to define mock.On call
- integration *model.Integration
func (*MockService_Expecter) ReleasePipeline ¶
func (_e *MockService_Expecter) ReleasePipeline(pipelineID interface{}) *MockService_ReleasePipeline_Call
ReleasePipeline is a helper method to define mock.On call
- pipelineID int64
func (*MockService_Expecter) TestConnection ¶
func (_e *MockService_Expecter) TestConnection(integration interface{}) *MockService_TestConnection_Call
TestConnection is a helper method to define mock.On call
- integration *model.Integration
type MockService_FetchSecret_Call ¶
MockService_FetchSecret_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'FetchSecret'
func (*MockService_FetchSecret_Call) Return ¶
func (_c *MockService_FetchSecret_Call) Return(s string, err error) *MockService_FetchSecret_Call
func (*MockService_FetchSecret_Call) Run ¶
func (_c *MockService_FetchSecret_Call) Run(run func(ctx context.Context, ref *model.ExternalSecretRef, userID int64, orgID int64, repoID int64, pipelineID int64)) *MockService_FetchSecret_Call
func (*MockService_FetchSecret_Call) RunAndReturn ¶
func (_c *MockService_FetchSecret_Call) RunAndReturn(run func(ctx context.Context, ref *model.ExternalSecretRef, userID int64, orgID int64, repoID int64, pipelineID int64) (string, error)) *MockService_FetchSecret_Call
type MockService_FetchSecretsBatch_Call ¶
MockService_FetchSecretsBatch_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'FetchSecretsBatch'
func (*MockService_FetchSecretsBatch_Call) Return ¶
func (_c *MockService_FetchSecretsBatch_Call) Return(stringToString map[string]string, err error) *MockService_FetchSecretsBatch_Call
func (*MockService_FetchSecretsBatch_Call) Run ¶
func (_c *MockService_FetchSecretsBatch_Call) Run(run func(ctx context.Context, refs []*model.ExternalSecretRef, userID int64, orgID int64, repoID int64, pipelineID int64)) *MockService_FetchSecretsBatch_Call
func (*MockService_FetchSecretsBatch_Call) RunAndReturn ¶
func (_c *MockService_FetchSecretsBatch_Call) RunAndReturn(run func(ctx context.Context, refs []*model.ExternalSecretRef, userID int64, orgID int64, repoID int64, pipelineID int64) (map[string]string, error)) *MockService_FetchSecretsBatch_Call
type MockService_GetProvider_Call ¶
MockService_GetProvider_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetProvider'
func (*MockService_GetProvider_Call) Return ¶
func (_c *MockService_GetProvider_Call) Return(provider integrations.Provider, err error) *MockService_GetProvider_Call
func (*MockService_GetProvider_Call) Run ¶
func (_c *MockService_GetProvider_Call) Run(run func(ctx context.Context, integrationID int64, pipelineID int64)) *MockService_GetProvider_Call
func (*MockService_GetProvider_Call) RunAndReturn ¶
func (_c *MockService_GetProvider_Call) RunAndReturn(run func(ctx context.Context, integrationID int64, pipelineID int64) (integrations.Provider, error)) *MockService_GetProvider_Call
type MockService_IntegrationCreate_Call ¶
MockService_IntegrationCreate_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IntegrationCreate'
func (*MockService_IntegrationCreate_Call) Return ¶
func (_c *MockService_IntegrationCreate_Call) Return(err error) *MockService_IntegrationCreate_Call
func (*MockService_IntegrationCreate_Call) Run ¶
func (_c *MockService_IntegrationCreate_Call) Run(run func(integration *model.Integration)) *MockService_IntegrationCreate_Call
func (*MockService_IntegrationCreate_Call) RunAndReturn ¶
func (_c *MockService_IntegrationCreate_Call) RunAndReturn(run func(integration *model.Integration) error) *MockService_IntegrationCreate_Call
type MockService_IntegrationDelete_Call ¶
MockService_IntegrationDelete_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IntegrationDelete'
func (*MockService_IntegrationDelete_Call) Return ¶
func (_c *MockService_IntegrationDelete_Call) Return(err error) *MockService_IntegrationDelete_Call
func (*MockService_IntegrationDelete_Call) Run ¶
func (_c *MockService_IntegrationDelete_Call) Run(run func(userID int64, integrationID int64)) *MockService_IntegrationDelete_Call
func (*MockService_IntegrationDelete_Call) RunAndReturn ¶
func (_c *MockService_IntegrationDelete_Call) RunAndReturn(run func(userID int64, integrationID int64) error) *MockService_IntegrationDelete_Call
type MockService_IntegrationFindByID_Call ¶
MockService_IntegrationFindByID_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IntegrationFindByID'
func (*MockService_IntegrationFindByID_Call) Return ¶
func (_c *MockService_IntegrationFindByID_Call) Return(integration *model.Integration, err error) *MockService_IntegrationFindByID_Call
func (*MockService_IntegrationFindByID_Call) Run ¶
func (_c *MockService_IntegrationFindByID_Call) Run(run func(integrationID int64)) *MockService_IntegrationFindByID_Call
func (*MockService_IntegrationFindByID_Call) RunAndReturn ¶
func (_c *MockService_IntegrationFindByID_Call) RunAndReturn(run func(integrationID int64) (*model.Integration, error)) *MockService_IntegrationFindByID_Call
type MockService_IntegrationFind_Call ¶
MockService_IntegrationFind_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IntegrationFind'
func (*MockService_IntegrationFind_Call) Return ¶
func (_c *MockService_IntegrationFind_Call) Return(integration *model.Integration, err error) *MockService_IntegrationFind_Call
func (*MockService_IntegrationFind_Call) Run ¶
func (_c *MockService_IntegrationFind_Call) Run(run func(userID int64, integrationID int64)) *MockService_IntegrationFind_Call
func (*MockService_IntegrationFind_Call) RunAndReturn ¶
func (_c *MockService_IntegrationFind_Call) RunAndReturn(run func(userID int64, integrationID int64) (*model.Integration, error)) *MockService_IntegrationFind_Call
type MockService_IntegrationListAccessible_Call ¶
MockService_IntegrationListAccessible_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IntegrationListAccessible'
func (*MockService_IntegrationListAccessible_Call) Return ¶
func (_c *MockService_IntegrationListAccessible_Call) Return(integrations1 []*model.Integration, err error) *MockService_IntegrationListAccessible_Call
func (*MockService_IntegrationListAccessible_Call) Run ¶
func (_c *MockService_IntegrationListAccessible_Call) Run(run func(userID int64, orgIDs []int64, repoIDs []int64, opts *model.ListOptions)) *MockService_IntegrationListAccessible_Call
func (*MockService_IntegrationListAccessible_Call) RunAndReturn ¶
func (_c *MockService_IntegrationListAccessible_Call) RunAndReturn(run func(userID int64, orgIDs []int64, repoIDs []int64, opts *model.ListOptions) ([]*model.Integration, error)) *MockService_IntegrationListAccessible_Call
type MockService_IntegrationList_Call ¶
MockService_IntegrationList_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IntegrationList'
func (*MockService_IntegrationList_Call) Return ¶
func (_c *MockService_IntegrationList_Call) Return(integrations1 []*model.Integration, err error) *MockService_IntegrationList_Call
func (*MockService_IntegrationList_Call) Run ¶
func (_c *MockService_IntegrationList_Call) Run(run func(userID int64, opts *model.ListOptions)) *MockService_IntegrationList_Call
func (*MockService_IntegrationList_Call) RunAndReturn ¶
func (_c *MockService_IntegrationList_Call) RunAndReturn(run func(userID int64, opts *model.ListOptions) ([]*model.Integration, error)) *MockService_IntegrationList_Call
type MockService_IntegrationUpdate_Call ¶
MockService_IntegrationUpdate_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IntegrationUpdate'
func (*MockService_IntegrationUpdate_Call) Return ¶
func (_c *MockService_IntegrationUpdate_Call) Return(err error) *MockService_IntegrationUpdate_Call
func (*MockService_IntegrationUpdate_Call) Run ¶
func (_c *MockService_IntegrationUpdate_Call) Run(run func(integration *model.Integration)) *MockService_IntegrationUpdate_Call
func (*MockService_IntegrationUpdate_Call) RunAndReturn ¶
func (_c *MockService_IntegrationUpdate_Call) RunAndReturn(run func(integration *model.Integration) error) *MockService_IntegrationUpdate_Call
type MockService_ReleasePipeline_Call ¶
MockService_ReleasePipeline_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ReleasePipeline'
func (*MockService_ReleasePipeline_Call) Return ¶
func (_c *MockService_ReleasePipeline_Call) Return() *MockService_ReleasePipeline_Call
func (*MockService_ReleasePipeline_Call) Run ¶
func (_c *MockService_ReleasePipeline_Call) Run(run func(pipelineID int64)) *MockService_ReleasePipeline_Call
func (*MockService_ReleasePipeline_Call) RunAndReturn ¶
func (_c *MockService_ReleasePipeline_Call) RunAndReturn(run func(pipelineID int64)) *MockService_ReleasePipeline_Call
type MockService_TestConnection_Call ¶
MockService_TestConnection_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'TestConnection'
func (*MockService_TestConnection_Call) Return ¶
func (_c *MockService_TestConnection_Call) Return(err error) *MockService_TestConnection_Call
func (*MockService_TestConnection_Call) Run ¶
func (_c *MockService_TestConnection_Call) Run(run func(integration *model.Integration)) *MockService_TestConnection_Call
func (*MockService_TestConnection_Call) RunAndReturn ¶
func (_c *MockService_TestConnection_Call) RunAndReturn(run func(integration *model.Integration) error) *MockService_TestConnection_Call